Methods for "normalizing" a SICD (sarpy.processing.normalize_sicd)
==================================================================

.. automodule:: sarpy.processing.normalize_sicd
    :members:
    :show-inheritance:
    :inherited-members:
